==> haskell-concurrent-supply-0.1.8-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-concurrent-supply.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: concurrent-supply
version: 0.1.8
id: concurrent-supply-0.1.8-KjbdmPZrM14GamX51jZtG8
key: concurrent-supply-0.1.8-KjbdmPZrM14GamX51jZtG8
license: BSD-3-Clause
copyright: Copyright (C) 2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/concurrent-supply/
synopsis: A fast concurrent unique identifier supply with a pure API
description:
    A fast supply of concurrent unique identifiers suitable for use
    within a single process. Once the initial '\''Supply'\'' has been initialized,
    the remainder of the API is pure. See "Control.Concurrent.Supply" for
    details.
category: Concurrency, Parallelism
abi: c5c7e5dd16e8340e499d190629019960
exposed: True
exposed-modules:
    Control.Concurrent.Supply
import-dirs: /usr/lib/ghc-8.4.3/site-local/concurrent-supply-0.1.8
library-dirs: /usr/lib/ghc-8.4.3/site-local/concurrent-supply-0.1.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/concurrent-supply-0.1.8
hs-libraries: HSconcurrent-supply-0.1.8-KjbdmPZrM14GamX51jZtG8
depends:
    base-4.11.1.0 hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    ghc-prim-0.5.2.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
haddock-interfaces: /usr/share/doc/haskell-concurrent-supply/html/concurrent-supply.haddock
haddock-html: /usr/share/doc/haskell-concurrent-supply/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-concurrent-supply-0.1.8-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-concurrent-supply.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: concurrent-supply
version: 0.1.8
id: concurrent-supply-0.1.8-1LBmd5pVf1GFtzwmxMt9rL
key: concurrent-supply-0.1.8-1LBmd5pVf1GFtzwmxMt9rL
license: BSD-3-Clause
copyright: Copyright (C) 2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/concurrent-supply/
synopsis: A fast concurrent unique identifier supply with a pure API
description:
    A fast supply of concurrent unique identifiers suitable for use
    within a single process. Once the initial '\''Supply'\'' has been initialized,
    the remainder of the API is pure. See "Control.Concurrent.Supply" for
    details.
category: Concurrency, Parallelism
abi: 049733cc324bfa538ba5859101f20235
exposed: True
exposed-modules:
    Control.Concurrent.Supply
import-dirs: /usr/lib/ghc-8.6.1/site-local/concurrent-supply-0.1.8
library-dirs: /usr/lib/ghc-8.6.1/site-local/concurrent-supply-0.1.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/concurrent-supply-0.1.8
hs-libraries: HSconcurrent-supply-0.1.8-1LBmd5pVf1GFtzwmxMt9rL
depends:
    base-4.12.0.0 ghc-prim-0.5.3
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
haddock-interfaces: /usr/share/doc/haskell-concurrent-supply/html/concurrent-supply.haddock
haddock-html: /usr/share/doc/haskell-concurrent-supply/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
